@@ -19,49 +19,49 @@
 #' data("dbces11")
 #' # degree
 #' dbces11 %>%
-#'   indirect_relations(type = "adjacency") %>%
-#'   aggregate_positions(type = "sum")
+#'     indirect_relations(type = "adjacency") %>%
+#'     aggregate_positions(type = "sum")
 #'
 #' # closeness centrality
 #' dbces11 %>%
-#'   indirect_relations(type = "dist_sp") %>%
-#'   aggregate_positions(type = "invsum")
+#'     indirect_relations(type = "dist_sp") %>%
+#'     aggregate_positions(type = "invsum")
 #'
 #' # betweenness centrality
 #' dbces11 %>%
-#'   indirect_relations(type = "depend_sp") %>%
-#'   aggregate_positions(type = "sum")
+#'     indirect_relations(type = "depend_sp") %>%
+#'     aggregate_positions(type = "sum")
 #'
 #' # eigenvector centrality
 #' dbces11 %>%
-#'   indirect_relations(type = "walks", FUN = walks_limit_prop) %>%
-#'   aggregate_positions(type = "sum")
+#'     indirect_relations(type = "walks", FUN = walks_limit_prop) %>%
+#'     aggregate_positions(type = "sum")
 #'
 #' # subgraph centrality
 #' dbces11 %>%
-#'   indirect_relations(type = "walks", FUN = walks_exp) %>%
-#'   aggregate_positions(type = "self")
+#'     indirect_relations(type = "walks", FUN = walks_exp) %>%
+#'     aggregate_positions(type = "self")
 #' @export
 aggregate_positions <- function(tau_x, type = "sum") {
-  if (!inherits(tau_x, "Matrix") & !is.matrix(tau_x)) {
-    stop("tau_x must be a matrix")
-  }
+    if (!inherits(tau_x, "Matrix") && !is.matrix(tau_x)) {
+        stop("tau_x must be a matrix")
+    }
 
-  if (type == "sum") {
-    return(rowSums(tau_x))
-  } else if (type == "prod") {
-    return(apply(tau_x, 1, prod))
-  } else if (type == "mean") {
-    return(rowMeans(tau_x))
-  } else if (type == "max") {
-    return(apply(tau_x, 1, max))
-  } else if (type == "min") {
-    return(apply(tau_x, 1, min))
-  } else if (type == "invsum") {
-    return(rowSums(tau_x)^-1)
-  } else if (type == "self") {
-    diag(tau_x)
-  } else {
-    stop(paste("type =", type, "is not supported. See function details for options."))
-  }
+    if (type == "sum") {
+        return(rowSums(tau_x))
+    } else if (type == "prod") {
+        return(apply(tau_x, 1, prod))
+    } else if (type == "mean") {
+        return(rowMeans(tau_x))
+    } else if (type == "max") {
+        return(apply(tau_x, 1, max))
+    } else if (type == "min") {
+        return(apply(tau_x, 1, min))
+    } else if (type == "invsum") {
+        return(rowSums(tau_x)^-1)
+    } else if (type == "self") {
+        diag(tau_x)
+    } else {
+        stop(paste("type =", type, "is not supported. See function details for options."))
+    }
 }
